==> geeklog-1.5.1-jp-extended-1.0.zip: geeklog-1.5.1-jp-extended-1.0/plugins/themedit/language/english.php <==
<?php

// +---------------------------------------------------------------------------+
// | Theme Editor Plugin for Geeklog - The Ultimate Weblog                     |
// +---------------------------------------------------------------------------|
// | geeklog/plugins/themedit/language/english.php                             |
// +---------------------------------------------------------------------------|
// | Copyright (C) 2006-2008 - geeklog AT mystral-kk DOT net                   |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------|
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software               |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA|
// |                                                                           |
// +---------------------------------------------------------------------------|

$LANG_CHARSET = 'iso-8859-1';

$LANG_THM = array(
    'plugin'            => 'Plugin',
	'access_denied'     => 'Access Denied',
	'access_denied_msg' => 'Only Root Users have Access to this Page.  Your user name and IP have been recorded.',
	'admin'		        => 'Theme Editor',
	'install_header'	=> 'Install/Uninstall Plugin',
	'installed'         => 'The Plugin is Installed',
	'uninstalled'       => 'The Plugin is Not Installed',
	'install_success'	=> 'Installation Successful',
	'install_failed'	=> 'Installation Failed -- See your error log to find out why.',
	'uninstall_msg'		=> 'Plugin Successfully Uninstalled',
	'install'           => 'Install',
	'uninstall'         => 'UnInstall',
    'warning'           => 'Warning! Plugin is still Enabled',
    'enabled'           => 'Disable plugin before uninstalling.',
    'readme'            => 'STOP! Before you press install please read the ',
    'installdoc'        => 'Install Document.',
    'installdoc_ja'     => 'Install Document (Japanese).',
	'menu_label'        => 'Theme Editor',
	'cc_label'          => 'Theme Editor',
	'script_disabled'   => 'JavaScript is disabled.  For better functionality, please set JavaScript on.',
	'theme_edited'      => 'Current Theme',
	'file_edited'       => 'Current File',
	'select'            => 'Select',
	'preview'           => 'Preview',
	'save'              => 'Save',
	'image'             => 'Image',
	'upload'            => 'Upload',
	'upload_header'     => 'Themedit - image',
	'return_to_editor'  => 'Return to theme editor',
	'change'            => 'Change',
	'file_too_large'    => 'The file is too large.',
	'file_type_unsupported' => 'The file type is not supported.',
	'upload_success'    => 'The file was successfully uploaded.',
	'upload_fail'       => 'The file was NOT uploaded.',
	'upload_attack'     => 'Possible file upload attack.',
	'delete'            => 'Delete all checked files',
	'delete_success'    => '%s file(s) were successfully deleted.',
	'delete_fail'       => '%s file(s) were NOT deleted.',
	'dir'               => 'Current directory',
	'file'              => 'File to upload (jpg, jpeg, png, gif)',
	'submit'            => 'Submit',
	'dest'              => 'Destination',
	'init'              => 'Initialize',
	'vars_available'    => 'Template Vars Available',
	'save_success'      => 'Saved the file successfully.',
	'save_fail'         => 'Error: coludn\'t save the file.',
	'init_success'      => 'Initialized the file successfully.',
	'init_fail'         => 'Error: coludn\'t initialize the file.',
	'not_writable'      => 'This file is not writable or does not exist.',
	'file_changed'      => "Themes and/or files are added and/or deleted.  To update the information stored in the database accordingly, click <a href='%s'>here</a>.",
	'help_advanced_editor' => 'advanced_editor: code to invoke FCKeditor',
	'help_button_advsearch' => 'button_advsearch: text for \'advanced search\' button',
	'help_button_search'   => 'button_search: text for \'search\' button',
	'help_centerblockfooter-span' => 'centerblockfooter-span:',
	'help_comments_with_count' => 'comments_with_count: comments with count',
	'help_contributedby_user' => 'contributedby_user: contributer of the story',
	'help_copyright_notice'   => 'copyright_notice: notice of your copyright',
	'help_css_url'         => 'css_url: URL to css file',
	'help_datetime'        => 'datetime: date and time',
	'help_direction'       => 'direction: direction to display texts',
	'help_edit_link' => 'edit_link: link for editing the story',
	'help_email_icon' => 'email_icon: icon for \'email this story to friends',
	'help_end_comments_anchortag' => 'end_comments_anchortag: end tag for comments',
	'help_end_contributedby_anchortag' => 'end_contributedby_anchortag: end tag for contributer',
	'help_end_storylink_anchortag' => 'end_storylink_anchortag: end tag for story links',
	'help_end_trackbacks_anchortag' => 'end_trackbacks_anchortag: end tag for trackbacks',
	'help_execution_textandtime' => 'execution_textandtime: text to display execution time',
	'help_feed_url'        => 'feed_url: URL to feed file',
	'help_geeklog_blocks'  => 'geeklog_blocks: place holder for system-default blocks',
	'help_geeklog_url'     => 'geeklog_url: URL to geeklog.net',
	'help_lang_contributed_by' => 'lang_contributed_by: text for \'contributed by\'',
	'help_lang_views' => 'lang_views:',
	'help_left_blocks'     => 'left_blocks: place holder for left blocks',
	'help_menu_elements'   => 'menu_elements: place holder for global menu',
	'help_page_selector' => 'page_selector: place holder for Google-like paging',
	'help_page_title'      => 'page_title: title of the page',
	'help_pdf_icon' => 'pdf_icon: icon for pdf',
	'help_plg_headercode'  => 'plg_headercode: JavaScript code plugins put into HTML header',
	'help_post_comment_link' => 'post_comment_link: link to post a comment',
	'help_powered_by'      => 'powered_by: text for \'powered_by\'',
	'help_print_icon' => 'print_icon: icon for printing',
	'help_readmore_link' => 'readmore_link: link to \'Read more\'',
	'help_right_blocks'    => 'right_blocks: place holder for right blocks',
	'help_site_logo'       => 'site_logo: URL to your site logo',
	'help_site_name'       => 'site_name: name of your site',
	'help_site_slogan'     => 'site_slogan: slogan your site shouts',
	'help_site_url'        => 'site_url: URL to your site',
	'help_start_comments_anchortag' => 'start_comments_anchortag: start tag for comments',
	'help_start_contributedby_anchortag' => 'start_contributedby_anchortag: start tag for contributer',
	'help_start_storylink_anchortag' => 'start_storylink_anchortag: start tag for story links',
	'help_start_trackbacks_anchortag' => 'start_trackbacks_anchortag: start tag for trackbacks',
	'help_story_anchortag_and_image' => 'story_anchortag_and_image: tag for story and image',
	'help_story_date' => 'story_date: date and time when the artcile was posted',
	'help_story_hits' => 'story_hits: how many times the story was read',
	'help_story_introtext' => 'story_introtext: introduction of the story',
	'help_story_title' => 'story_title: the title of the story',
	'help_theme'           => 'theme: name of theme your Geeklog uses',
	'help_trackbacks_with_count' => 'trackbacks_with_count: trackbacks with count',
	'help_welcome_msg'     => 'welcome_msg: message displayed at the top of your site',
	'style.css'                        => 'Style Sheet(style.css)',
	'style_jp.css'                     => 'Style Sheet(stlye_jp.css)',
	'style_forum.css'                  => 'Style Sheet(stlye_forum.css)',
	'header.thtml'                     => 'Header',
	'footer.thtml'                     => 'Footer',
	'leftblocks.thtml'                 => 'Left Blocks',
	'blockheader-left.thtml'           => 'Left Block Header',
	'blockfooter-left.thtml'           => 'Left Block Footer',
	'rightblocks.thtml'                => 'Right Blocks',
	'blockheader-right.thtml'          => 'Right Block Header',
	'blockfooter-right.thtml'          => 'Right Block Footer',
	'blockheader-list.thtml'           => 'Block Header with list (GL-1.5.0+)',
	'blockfooter-list.thtml'           => 'Block Footer with list (GL-1.5.0+)',
	'storytext.thtml'                  => 'Story Text',
	'featuredstorytext.thtml'          => 'Featured Story Text',
	'archivestorytext.thtml'           => 'Archived Story Text',
	'article/article.thtml'            => 'Article',
	'article/printable.thtml'          => 'Article (Printable)',
	'menuitem.thtml'                   => 'Menu Item',
	'menuitem_last.thtml'              => 'Menu Item (Last)',
	'menuitem_none.thtml'              => 'Menu Item (None)',
	'list.thtml'                       => 'List',
	'listitem.thtml'                   => 'List Item',
	'loginform.thtml'                  => 'Login Form',
	'profiles/contactuserform.thtml'   => 'Contact User Form',
	'profiles/contactauthorform.thtml' => 'Contact Author Form',
	'preferences/profile.thtml'        => 'Profile (Preference)',
	'users/profile.thtml'              => 'Profile (Users)',
	'search/searchform.thtml'          => 'Search Form',
	'search/searchresults.thtml'       => 'Search Results',
	'submit/submitevent.thtml'         => 'Submit Event',
	'submit/submitloginrequired.thtml' => 'Submit Login Required',
	'submit/submitstory.thtml'         => 'Submit Story by user (GL-1.5.0+)',
	'submit/submitstory_advacned.thtml' => 'Submit Story by user (Advanced Editor) (GL-1.5.0+)',
	'users/newpassword.thtml'          => 'New Password',
	'users/getpasswordform.thtml'      => 'Get Password Form',
	'users/loginform.thtml'            => 'Login Form',
	'users/registrationform.thtml'     => 'Registration Form',
	'users/storyrow.thtml'             => 'Story Row',
	'users/commentrow.thtml'           => 'Comment Row',

	'menu_admin_home'                  => 'Admin HOME',
	'menu_file'                        => 'Files',
	'menu_image'                       => 'Images',
	
	'help_page_site_splitter'          => 'page_site_splitter: ?',
	'help_lang_attribute'              => 'lang_attribute: lang attribute',
	'help_xhtml'                       => 'xhtml: tag for XHTML',
	'help_rel_links'                   => 'rel_links: ?',
	'help_block_help'                  => 'block_help: Block Help',
	'help_block_title'                 => 'block_title: Block Title',
	'help_contributedby_author'        => 'contributedby_author: ?',
	'help_plugin_itemdisplay'          => 'plugin_itemdisplay: ',
	'help_edit_icon'                   => 'edit_icon: Icon for editing',
	'help_story_title_link'            => 'story_title_link: Link to Story Title',
	'help_story_bodytext'              => 'story_bodytext: Body text of Story',
	'help_commentbar'                  => 'commentbar: Comment Bae',
	'help_whats_related'               => 'whats_related: What\'s Related',
	'help_formatted_article'           => 'formatted_article: Formated Article',
	'help_story_options'               => 'story_options: Story Options',
	'help_trackback'                   => 'trackback: Trackback',
	'help_article_url'                 => 'article_url: URL of Article',
	'help_story_author'                => 'story_author: Story Author',
	'help_lang_contributedby'          => 'lang_contributedby: [L]Contributed By',
	'help_menuitem_text'               => 'menuitem_text: Text of Menu Item',
	'help_menuitem_url'                => 'menuitem_url: URL of Menu Item',
	'help_list_class'                  => 'list_class: Class of List',
	'help_list_items'                  => 'list_items: List Items',
	'help_list_item'                   => 'list_item: List Item',
	'help_lang_forgetpassword'         => 'lang_forgetpassword: [L]Forget Password?',
	'help_lang_username'               => 'lang_username: [L]User Name',
	'help_lang_login'                  => 'lang_login: [L]Login',
	'help_openid_login'                => 'openid_login: Login with OpenID',
	'help_lang_password'               => 'lang_password: [L]Password',
	'help_services'                    => 'services: Services',
	'help_lang_signup'                 => 'lang_signup: [L]Signup',
	'help_captcha'                     => 'captcha: CAPTCHA',
	'help_lang_subject'                => 'lang_subject: [L]Subject',
	'help_message'                     => 'message: Message',
	'help_useremail'                   => 'useremail: User Email',
	'help_lang_description'            => 'lang_description: [L]Description',
	'help_lang_submit'                 => 'lang_submit: [L]Submit',
	'help_username'                    => 'username: User Name',
	'help_lang_message'                => 'lang_message: [L]Message',
	'help_lang_useremail'              => 'lang_useremail: [L]User Email',
	'help_subject'                     => 'subject: Subject',
	'help_lang_nohtml'                 => 'lang_nohtml: [L]No HTML',
	'help_uid'                         => 'uid: User ID',
	'help_lang_fromname'               => 'lang_fromname: [L]Name of Email Sender',
	'help_lang_toname'                 => 'lang_toname: [L]Name of Email Recipient',
	'help_toname'                      => 'toname: Recipient',
	'help_email'                       => 'email: Email',
	'help_lang_sendmessage'            => 'lang_sendmessage: [L]Send Message',
	'help_lang_warning'                => 'lang_warning: [L]Warning',
	'help_start_block_mailstory2friend' => 'start_block_mailstory2friend: Start of Block of Mail Story to Friend',
	'help_end_block'                   => 'end_block: End of Block',
	'help_lang_shortmessage'           => 'lang_shortmessage: [L]Message',
	'help_name'                        => 'name: Name',
	'help_story_id'                    => 'story_id: Story ID',
	'help_lang_fromemailaddress'       => 'lang_fromemailaddress: [L]Email Address of Sender',
	'help_lang_toemailaddress'         => 'lang_toemailaddress: [L]Email Address of Recipient',
	'help_shortmsg'                    => 'shortmsg: Message',
	'help_toemail'                     => 'toemail: Email Address of Recipient',
);

// Localization of the Admin Configuration UI
$LANG_configsections['themedit'] = array(
    'label' => 'Theme Editor',
    'title' => 'Theme Editor Config'
);

/**
* For Config UI
*/
$LANG_confignames['themedit'] = array(
	'enable_all_themes'      => 'Allow editing all themes',
	'enable_all_files'       => 'Allow editing all files',
	'allowed_themes'         => 'Themes allowed to be edited',
	'allowed_files'          => 'Files allowed to be edited',
    'resync_database'        => 'Resync method',
	'allow_upload'           => 'Allow uploading files',
	'image_width'            => 'Width of thumbnail images in pixels',
	'image_height'           => 'Height of thumbnail images in pixels',
	'image_max_col'          => 'Num of columns of thumbnail images',
	'upload_max_size'        => 'Maximum size of files to be uploaded in bytes',
	'enable_csrf_protection' => 'Enable CSRF protection',
);

$LANG_configsubgroups['themedit'] = array(
    'sg_main' => 'Main'
);

$LANG_fs['themedit'] = array(
    'fs_main'   => 'Main Config',
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['themedit'] = array(
    0 => array('Yes' => true, 'No' => false),
	1 => array(
			'Resync manually' => 'manual', 'Resync Automatically' => 'auto', 'Do not resync' => 'ignore'
		),
	
);

==> geeklog-2.0.0-jp-extended-1.0.zip: geeklog-2.0.0-jp-extended-1.0/plugins/themedit/language/english.php <==
<?php

// +---------------------------------------------------------------------------+
// | Theme Editor Plugin for Geeklog - The Ultimate Weblog                     |
// +---------------------------------------------------------------------------|
// | geeklog/plugins/themedit/language/english.php                             |
// +---------------------------------------------------------------------------|
// | Copyright (C) 2006-2011 - geeklog AT mystral-kk DOT net                   |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------|
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software               |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA|
// |                                                                           |
// +---------------------------------------------------------------------------|

$LANG_THM = array(
    'plugin'            => 'Plugin',
	'access_denied'     => 'Access Denied',
	'access_denied_msg' => 'Only Root Users have Access to this Page.  Your user name and IP have been recorded.',
	'admin'		        => 'Theme Editor',
	'install_header'	=> 'Install/Uninstall Plugin',
	'installed'         => 'The Plugin is Installed',
	'uninstalled'       => 'The Plugin is Not Installed',
	'install_success'	=> 'Installation Successful',
	'install_failed'	=> 'Installation Failed -- See your error log to find out why.',
	'uninstall_msg'		=> 'Plugin Successfully Uninstalled',
	'install'           => 'Install',
	'uninstall'         => 'UnInstall',
    'warning'           => 'Warning! Plugin is still Enabled',
    'enabled'           => 'Disable plugin before uninstalling.',
    'readme'            => 'STOP! Before you press install please read the ',
    'installdoc'        => 'Install Document.',
    'installdoc_ja'     => 'Install Document (Japanese).',
	'menu_label'        => 'Theme Editor',
	'cc_label'          => 'Theme Editor',
	'script_disabled'   => 'JavaScript is disabled.  For better functionality, please set JavaScript on.',
	'theme_edited'      => 'Current Theme',
	'file_edited'       => 'Current File',
	'select'            => 'Select',
	'preview'           => 'Preview',
	'save'              => 'Save',
	'image'             => 'Image',
	'upload'            => 'Upload',
	'upload_header'     => 'Themedit - image',
	'return_to_editor'  => 'Return to theme editor',
	'change'            => 'Change',
	'file_too_large'    => 'The file is too large.',
	'file_type_unsupported' => 'The file type is not supported.',
	'upload_success'    => 'The file was successfully uploaded.',
	'upload_fail'       => 'The file was NOT uploaded.',
	'upload_attack'     => 'Possible file upload attack.',
	'delete'            => 'Delete all checked files',
	'delete_success'    => '%s file(s) were successfully deleted.',
	'delete_fail'       => '%s file(s) were NOT deleted.',
	'dir'               => 'Current directory',
	'file'              => 'File to upload (jpg, jpeg, png, gif)',
	'submit'            => 'Submit',
	'dest'              => 'Destination',
	'init'              => 'Initialize',
	'vars_available'    => 'Template Vars Available',
	'save_success'      => 'Saved the file successfully.',
	'save_fail'         => 'Error: coludn\'t save the file.',
	'init_success'      => 'Initialized the file successfully.',
	'init_fail'         => 'Error: coludn\'t initialize the file.',
	'not_writable'      => 'This file is not writable or does not exist.',
	'file_changed'      => "Themes and/or files are added and/or deleted.  To update the information stored in the database accordingly, click <a href='%s'>here</a>.",
	'help_advanced_editor' => 'advanced_editor: code to invoke FCKeditor',
	'help_button_advsearch' => 'button_advsearch: text for \'advanced search\' button',
	'help_button_search'   => 'button_search: text for \'search\' button',
	'help_centerblockfooter-span' => 'centerblockfooter-span:',
	'help_comments_with_count' => 'comments_with_count: comments with count',
	'help_contributedby_user' => 'contributedby_user: contributer of the story',
	'help_copyright_notice'   => 'copyright_notice: notice of your copyright',
	'help_css_url'         => 'css_url: URL to css file',
	'help_datetime'        => 'datetime: date and time',
	'help_direction'       => 'direction: direction to display texts',
	'help_edit_link' => 'edit_link: link for editing the story',
	'help_email_icon' => 'email_icon: icon for \'email this story to friends',
	'help_end_comments_anchortag' => 'end_comments_anchortag: end tag for comments',
	'help_end_contributedby_anchortag' => 'end_contributedby_anchortag: end tag for contributer',
	'help_end_storylink_anchortag' => 'end_storylink_anchortag: end tag for story links',
	'help_end_trackbacks_anchortag' => 'end_trackbacks_anchortag: end tag for trackbacks',
	'help_execution_textandtime' => 'execution_textandtime: text to display execution time',
	'help_feed_url'        => 'feed_url: URL to feed file',
	'help_geeklog_blocks'  => 'geeklog_blocks: place holder for system-default blocks',
	'help_geeklog_url'     => 'geeklog_url: URL to geeklog.net',
	'help_lang_contributed_by' => 'lang_contributed_by: text for \'contributed by\'',
	'help_lang_views' => 'lang_views:',
	'help_left_blocks'     => 'left_blocks: place holder for left blocks',
	'help_menu_elements'   => 'menu_elements: place holder for global menu',
	'help_page_selector' => 'page_selector: place holder for Google-like paging',
	'help_page_title'      => 'page_title: title of the page',
	'help_pdf_icon' => 'pdf_icon: icon for pdf',
	'help_plg_headercode'  => 'plg_headercode: JavaScript code plugins put into HTML header',
	'help_post_comment_link' => 'post_comment_link: link to post a comment',
	'help_powered_by'      => 'powered_by: text for \'powered_by\'',
	'help_print_icon' => 'print_icon: icon for printing',
	'help_readmore_link' => 'readmore_link: link to \'Read more\'',
	'help_right_blocks'    => 'right_blocks: place holder for right blocks',
	'help_site_logo'       => 'site_logo: URL to your site logo',
	'help_site_name'       => 'site_name: name of your site',
	'help_site_slogan'     => 'site_slogan: slogan your site shouts',
	'help_site_url'        => 'site_url: URL to your site',
	'help_start_comments_anchortag' => 'start_comments_anchortag: start tag for comments',
	'help_start_contributedby_anchortag' => 'start_contributedby_anchortag: start tag for contributer',
	'help_start_storylink_anchortag' => 'start_storylink_anchortag: start tag for story links',
	'help_start_trackbacks_anchortag' => 'start_trackbacks_anchortag: start tag for trackbacks',
	'help_story_anchortag_and_image' => 'story_anchortag_and_image: tag for story and image',
	'help_story_date' => 'story_date: date and time when the artcile was posted',
	'help_story_hits' => 'story_hits: how many times the story was read',
	'help_story_introtext' => 'story_introtext: introduction of the story',
	'help_story_title' => 'story_title: the title of the story',
	'help_theme'           => 'theme: name of theme your Geeklog uses',
	'help_trackbacks_with_count' => 'trackbacks_with_count: trackbacks with count',
	'help_welcome_msg'     => 'welcome_msg: message displayed at the top of your site',
	'style.css'                        => 'Style Sheet(style.css)',
	'style_jp.css'                     => 'Style Sheet(stlye_jp.css)',
	'style_forum.css'                  => 'Style Sheet(stlye_forum.css)',
	'header.thtml'                     => 'Header',
	'footer.thtml'                     => 'Footer',
	'leftblocks.thtml'                 => 'Left Blocks',
	'blockheader-left.thtml'           => 'Left Block Header',
	'blockfooter-left.thtml'           => 'Left Block Footer',
	'rightblocks.thtml'                => 'Right Blocks',
	'blockheader-right.thtml'          => 'Right Block Header',
	'blockfooter-right.thtml'          => 'Right Block Footer',
	'blockheader-list.thtml'           => 'Block Header with list (GL-1.5.0+)',
	'blockfooter-list.thtml'           => 'Block Footer with list (GL-1.5.0+)',
	'storytext.thtml'                  => 'Story Text',
	'featuredstorytext.thtml'          => 'Featured Story Text',
	'archivestorytext.thtml'           => 'Archived Story Text',
	'article/article.thtml'            => 'Article',
	'article/printable.thtml'          => 'Article (Printable)',
	'menuitem.thtml'                   => 'Menu Item',
	'menuitem_last.thtml'              => 'Menu Item (Last)',
	'menuitem_none.thtml'              => 'Menu Item (None)',
	'list.thtml'                       => 'List',
	'listitem.thtml'                   => 'List Item',
	'loginform.thtml'                  => 'Login Form',
	'profiles/contactuserform.thtml'   => 'Contact User Form',
	'profiles/contactauthorform.thtml' => 'Contact Author Form',
	'preferences/profile.thtml'        => 'Profile (Preference)',
	'users/profile.thtml'              => 'Profile (Users)',
	'search/searchform.thtml'          => 'Search Form',
	'search/searchresults.thtml'       => 'Search Results',
	'submit/submitevent.thtml'         => 'Submit Event',
	'submit/submitloginrequired.thtml' => 'Submit Login Required',
	'submit/submitstory.thtml'         => 'Submit Story by user (GL-1.5.0+)',
	'submit/submitstory_advacned.thtml' => 'Submit Story by user (Advanced Editor) (GL-1.5.0+)',
	'users/newpassword.thtml'          => 'New Password',
	'users/getpasswordform.thtml'      => 'Get Password Form',
	'users/loginform.thtml'            => 'Login Form',
	'users/registrationform.thtml'     => 'Registration Form',
	'users/storyrow.thtml'             => 'Story Row',
	'users/commentrow.thtml'           => 'Comment Row',

	'menu_admin_home'                  => 'Admin HOME',
	'menu_file'                        => 'Files',
	'menu_image'                       => 'Images',
	
	'help_page_site_splitter'          => 'page_site_splitter: ?',
	'help_lang_attribute'              => 'lang_attribute: lang attribute',
	'help_xhtml'                       => 'xhtml: tag for XHTML',
	'help_rel_links'                   => 'rel_links: ?',
	'help_block_help'                  => 'block_help: Block Help',
	'help_block_title'                 => 'block_title: Block Title',
	'help_contributedby_author'        => 'contributedby_author: ?',
	'help_plugin_itemdisplay'          => 'plugin_itemdisplay: ',
	'help_edit_icon'                   => 'edit_icon: Icon for editing',
	'help_story_title_link'            => 'story_title_link: Link to Story Title',
	'help_story_bodytext'              => 'story_bodytext: Body text of Story',
	'help_commentbar'                  => 'commentbar: Comment Bae',
	'help_whats_related'               => 'whats_related: What\'s Related',
	'help_formatted_article'           => 'formatted_article: Formated Article',
	'help_story_options'               => 'story_options: Story Options',
	'help_trackback'                   => 'trackback: Trackback',
	'help_article_url'                 => 'article_url: URL of Article',
	'help_story_author'                => 'story_author: Story Author',
	'help_lang_contributedby'          => 'lang_contributedby: [L]Contributed By',
	'help_menuitem_text'               => 'menuitem_text: Text of Menu Item',
	'help_menuitem_url'                => 'menuitem_url: URL of Menu Item',
	'help_list_class'                  => 'list_class: Class of List',
	'help_list_items'                  => 'list_items: List Items',
	'help_list_item'                   => 'list_item: List Item',
	'help_lang_forgetpassword'         => 'lang_forgetpassword: [L]Forget Password?',
	'help_lang_username'               => 'lang_username: [L]User Name',
	'help_lang_login'                  => 'lang_login: [L]Login',
	'help_openid_login'                => 'openid_login: Login with OpenID',
	'help_lang_password'               => 'lang_password: [L]Password',
	'help_services'                    => 'services: Services',
	'help_lang_signup'                 => 'lang_signup: [L]Signup',
	'help_captcha'                     => 'captcha: CAPTCHA',
	'help_lang_subject'                => 'lang_subject: [L]Subject',
	'help_message'                     => 'message: Message',
	'help_useremail'                   => 'useremail: User Email',
	'help_lang_description'            => 'lang_description: [L]Description',
	'help_lang_submit'                 => 'lang_submit: [L]Submit',
	'help_username'                    => 'username: User Name',
	'help_lang_message'                => 'lang_message: [L]Message',
	'help_lang_useremail'              => 'lang_useremail: [L]User Email',
	'help_subject'                     => 'subject: Subject',
	'help_lang_nohtml'                 => 'lang_nohtml: [L]No HTML',
	'help_uid'                         => 'uid: User ID',
	'help_lang_fromname'               => 'lang_fromname: [L]Name of Email Sender',
	'help_lang_toname'                 => 'lang_toname: [L]Name of Email Recipient',
	'help_toname'                      => 'toname: Recipient',
	'help_email'                       => 'email: Email',
	'help_lang_sendmessage'            => 'lang_sendmessage: [L]Send Message',
	'help_lang_warning'                => 'lang_warning: [L]Warning',
	'help_start_block_mailstory2friend' => 'start_block_mailstory2friend: Start of Block of Mail Story to Friend',
	'help_end_block'                   => 'end_block: End of Block',
	'help_lang_shortmessage'           => 'lang_shortmessage: [L]Message',
	'help_name'                        => 'name: Name',
	'help_story_id'                    => 'story_id: Story ID',
	'help_lang_fromemailaddress'       => 'lang_fromemailaddress: [L]Email Address of Sender',
	'help_lang_toemailaddress'         => 'lang_toemailaddress: [L]Email Address of Recipient',
	'help_shortmsg'                    => 'shortmsg: Message',
	'help_toemail'                     => 'toemail: Email Address of Recipient',
);

// Localization of the Admin Configuration UI
$LANG_configsections['themedit'] = array(
    'label' => 'Theme Editor',
    'title' => 'Theme Editor Config'
);

/**
* For Config UI
*/
$LANG_confignames['themedit'] = array(
	'enable_all_themes'      => 'Allow editing all themes',
	'enable_all_files'       => 'Allow editing all files',
	'allowed_themes'         => 'Themes allowed to be edited',
	'allowed_files'          => 'Files allowed to be edited',
    'resync_database'        => 'Resync method',
	'allow_upload'           => 'Allow uploading files',
	'image_width'            => 'Width of thumbnail images in pixels',
	'image_height'           => 'Height of thumbnail images in pixels',
	'image_max_col'          => 'Num of columns of thumbnail images',
	'upload_max_size'        => 'Maximum size of files to be uploaded in bytes',
//	'enable_csrf_protection' => 'Enable CSRF protection',
);

$LANG_configsubgroups['themedit'] = array(
    'sg_main' => 'Main'
);

$LANG_fs['themedit'] = array(
    'fs_main'   => 'Main Config',
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['themedit'] = array(
    0 => array('Yes' => TRUE, 'No' => FALSE),
	1 => array(
			'Resync manually' => 'manual', 'Resync Automatically' => 'auto', 'Do not resync' => 'ignore'
		),
);
